﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.Serialization;
using System.Security.Cryptography.X509Certificates;
using System.ServiceModel;
using System.Text;
using System.Xml;
using RKRD.Registry.NRZP.Service;

namespace RKRD.Registry.NRZP.ServiceTestClient
{
	internal class Program
	{
		private const string ARG_FILE = "Args.txt";

		private static void Main(string[] args)
		{
			try
			{
				string url;
				X509Certificate2 cert;
				EnumMethod method;
				int parStartIndex;
				int parCount;
				string externiUzivatelLogin;
				string externiUzivatelJmenoAPrijmeni;

				if (!Validate(args, out url, out cert, out  method, out parStartIndex, out parCount, out externiUzivatelLogin, out externiUzivatelJmenoAPrijmeni))
				{
					Console.ReadKey();
					return;
				}

				PrintHeader();

				Console.WriteLine("Volám url: {0}", url);

				EndpointAddress remoteAddress = new EndpointAddress(url);
				bool useHttps = new Uri(url).Scheme.Equals("https", StringComparison.OrdinalIgnoreCase);
				TimeSpan tmo = new TimeSpan(0, 0, 60);
				WSHttpBinding binding = new WSHttpBinding(useHttps ? SecurityMode.TransportWithMessageCredential : SecurityMode.Message)
				{
					MaxBufferPoolSize = 10000000,
					MaxReceivedMessageSize = 10000000,
					ReaderQuotas =
					{
						MaxStringContentLength = 10000000,
						MaxArrayLength = 10000000
					},
					SendTimeout = tmo,
					ReceiveTimeout = tmo
				};
				if (cert != null)
				{
					binding.Security.Message.ClientCredentialType = MessageCredentialType.Certificate;
				}

				NrzpServiceClient client = new NrzpServiceClient(binding, remoteAddress);
				if (cert != null)
				{
					if (client.ClientCredentials != null) client.ClientCredentials.ClientCertificate.Certificate = cert;
				}


				ResultCrate result = null;
				string arg0 = GetArgNo(args, parStartIndex, parCount, 0);
				string arg1 = GetArgNo(args, parStartIndex, parCount, 1);
				string arg2 = GetArgNo(args, parStartIndex, parCount, 2);

				switch (method)
				{
					case EnumMethod.zapispracovnika:
						result = ZapisPracovnika(client, arg0, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.ctiseznamciselniku:
						result = CtiSeznamCiselniku(client);
						break;
					case EnumMethod.cticiselnik:
						result = CtiCiselnik(client, arg0, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.ctipodlepracovnikcislo:
						result = CtiPodlePracovnikCislo(client, arg0, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.ctipodleudaju:
						//result = CtiPodleUdaju(client, arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7);
						result = CtiPodleUdaju(client, arg0, arg1, arg2, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.ctipodleaifo:
						result = CtiPodleAifo(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smazzamestnani:
						result = SmazZamestnani(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smazvykonpovolani:
						result = SmazVykonPovolani(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smaztitul:
						result = SmazTitul(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smazpovolani:
						result = SmazPovolani(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smazkmen:
						result = SmazKmen(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smazzvlastniodbornouzpusobilost:
						result = SmazZvlastniOdbornouZpusobilost(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smazspecializovanouzpusobilost:
						result = SmazSpecializovanouZpusobilost(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					case EnumMethod.smazodbornouzpusobilost:
						result = SmazOdbornouZpusobilost(client, arg0, arg1, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni);
						break;
					//case EnumMethod.import:
					//	break;
					default:
						throw new ArgumentOutOfRangeException();
				}

				if (result == null)
				{
					Console.WriteLine("NOk");
					return;
				}

				Console.WriteLine("Ok");
				Console.WriteLine("Metoda: {0}", method);
				Console.WriteLine("Stav: {0}", result.Stav);
				Console.WriteLine("IdDavky: {0}", result.IdDavky);
				Console.WriteLine("Zpráva: {0}", result.Message);
				Console.WriteLine("Odpověd: {0}", result.Response);
			}
			catch (Exception ex)
			{
				Console.WriteLine(ex.Message);
				Console.WriteLine(ex.StackTrace);
			}

			Console.WriteLine("\n\nHotovo. Pokračujte stiskem libovolné klávesy...");
			Console.ReadKey();
		}

		private static string GetArgNo(string[] args, int parStartIndex, int parCount, int nth)
		{
			string result = null;
			if (/*parCount < nth &&*/ parStartIndex + nth < args.Count())
			{
				result = args[parStartIndex + nth];
			}

			return result;
		}

		private static bool Validate(string[] args, out string url, out X509Certificate2 cert, out EnumMethod method, out int parStartIndex, out int commandArgCount, out string externiUzivatelLogin, out string externiUzivatelJmenoAPrijmeni)
		{
			List<string> errors = new List<string>();

			if (!args.Any())
			{
				url = null;
				method = EnumMethod.zapispracovnika;
				parStartIndex = 0;
				commandArgCount = 0;
				cert = null;
				externiUzivatelLogin = string.Empty;
				externiUzivatelJmenoAPrijmeni = string.Empty;

				PrintUsage();
				return false;
			}

			externiUzivatelLogin = (!string.IsNullOrEmpty(args[0])) ? args[0].ToLowerInvariant() : null;

			if (string.IsNullOrEmpty(externiUzivatelLogin))
			{
				errors.Add("Není zadán login externího uživatele.");
			}

			externiUzivatelJmenoAPrijmeni = (args.Count() > 1 && !string.IsNullOrEmpty(args[1])) ? args[1].ToLowerInvariant() : null;

			if (string.IsNullOrEmpty(externiUzivatelJmenoAPrijmeni))
			{
				errors.Add("Není zadáno jméno a příjmení externího uživatele.");
			}

			string enviroment = (args.Count() > 2 && !string.IsNullOrEmpty(args[2])) ? args[2].ToLowerInvariant() : null;

			url = GetUrl(enviroment, errors);

			method = GetCommand(args, enviroment, out parStartIndex, out commandArgCount, errors);

			cert = GetCertificate(args, enviroment, errors);

			Console.WriteLine(string.Join(Environment.NewLine, errors));

			return !errors.Any();
		}

		private static X509Certificate2 GetCertificate(string[] args, string enviroment, List<string> errors)
		{
			X509Certificate2 result = null;
			if (enviroment != "localhost")
			{
				string certificateFile = args.Count() > 3 ? args[3] : null;
				string certificatePassword = args.Count() > 4 ? args[4] : null;

				if (string.IsNullOrEmpty(certificateFile))
				{
					errors.Add("Není zadán soubor s certifikátem.");
				}
				else
				{
					result = new X509Certificate2(certificateFile, certificatePassword, X509KeyStorageFlags.MachineKeySet | X509KeyStorageFlags.PersistKeySet);
					if (!result.HasPrivateKey)
					{
						errors.Add("Certifikát nemá privátní klíč.");
					}
				}
			}

			return result;
		}

		private static EnumMethod GetCommand(string[] args, string enviroment, out int parStartIndex, out int commandArgCount, List<string> errors)
		{
			EnumMethod enumMethod = EnumMethod.zapispracovnika;
			string command;
			commandArgCount = 0;

			if (enviroment == "localhost")
			{
				command = args.Count() > 3 ? args[3] : null;
				parStartIndex = 4;
			}
			else
			{
				command = args.Count() > 5 ? args[5] : null;
				parStartIndex = 6;
			}

			string errCmdNotExist = string.Format("Neznámý příkaz. Použijte jeden z příkazů: {0}", string.Join(", ", Enum.GetNames(typeof(EnumMethod))));
			if (string.IsNullOrEmpty(command))
			{
				errors.Add(errCmdNotExist);
				return enumMethod;
			}

			command = command.ToLowerInvariant();

			if (!Enum.IsDefined(typeof(EnumMethod), command))
			{
				errors.Add(errCmdNotExist);
				return enumMethod;
			}

			try
			{
				enumMethod = (EnumMethod)Enum.Parse(typeof(EnumMethod), command);
			}
			catch (ArgumentException)
			{
				errors.Add(errCmdNotExist);
				return 0;
			}

			int currentArgsCount = args.Count() - parStartIndex;
			int expectedArgsCount = 0;

			switch (enumMethod)
			{
				case EnumMethod.zapispracovnika:
					expectedArgsCount = 1;
					break;
				case EnumMethod.ctiseznamciselniku:
					expectedArgsCount = 0;
					break;
				case EnumMethod.cticiselnik:
					expectedArgsCount = 1;
					break;
				case EnumMethod.ctipodlepracovnikcislo:
					expectedArgsCount = 1;
					break;
				case EnumMethod.ctipodleudaju:
					//expectedArgsCount = 8;
					expectedArgsCount = 1;
					break;
				case EnumMethod.ctipodleaifo:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smazzamestnani:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smazvykonpovolani:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smaztitul:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smazpovolani:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smazkmen:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smazzvlastniodbornouzpusobilost:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smazspecializovanouzpusobilost:
					expectedArgsCount = 2;
					break;
				case EnumMethod.smazodbornouzpusobilost:
					expectedArgsCount = 2;
					break;
				//case EnumMethod.import:
				//	expectedArgsCount = 0;
				//	break;
				default:
					errors.Add(errCmdNotExist);
					break;
			}

			if (currentArgsCount != expectedArgsCount)
			{
				errors.Add(string.Format("Neodpovídající počet argumentů pro metodu {0}. Zadaný: {1} Očekávaný: {2}",
					command, currentArgsCount, expectedArgsCount));
			}

			return enumMethod;
		}

		private static string GetUrl(string enviroment, List<string> errors)
		{
			if (string.IsNullOrEmpty(enviroment))
			{
				return null;
			}

			string url = string.Empty;

			switch (enviroment)
			{
				case "localhost":
					url = "http://localhost:61034/Registr/NRZP/Service/NRZPService.svc";
					break;
				case "rkrdlab":
					url = "https://ws.rkrdlab.i.cz/Registr/NRZP/";
					break;
				case "ereg2":
					url = "https://eregws2.ksrzis.cz/Registr/NRZP/";
					break;
				case "prod":
					url = "https://eregws.ksrzis.cz/Registr/NRZP/";
					break;
				default:
					errors.Add("Platné prostředí jsou enviroments: rkrdlab, ereg2, prod, localhost");
					break;
			}

			return url;
		}

		private static void PrintHeader()
		{
			Console.WriteLine(@"---------------------------------------------------" + Environment.NewLine +
								  "--  NRZP Ws Test                                ---" + Environment.NewLine +
								  "---------------------------------------------------");
		}

		private static void PrintUsage()
		{
			string file = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, ARG_FILE);
			if (File.Exists(file))
			{
				foreach (var line in File.ReadAllLines(file))
				{
					Console.WriteLine(line);
				}
			}
		}

		#region Metody sluzby

		private static ResultCrate ZapisPracovnika(NrzpServiceClient client, string fileName, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			SeznamPracovnikuType exportData;
			try
			{
				exportData = DeserializeObsah<SeznamPracovnikuType>(fileName, "SeznamPracovniku", "http://i.cz/ns/nrzp/schemas/nrzpWs/v1");
			}
			catch (Exception)
			{
				Console.WriteLine("Obsah davky se nepodařilo deserializovat");
				throw;
			}

			SeznamPracovnikuResponseType response;
			ImportStavType stav;
			string message;
			int idDavky = client.ZapisPracovnika(exportData, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out stav, out message, out response);
			return new ResultCrate
					   {
						   IdDavky = idDavky,
						   Stav = stav,
						   Message = message,
						   Response = SerializeToString(response)
					   };
		}

		private static ResultCrate CtiSeznamCiselniku(NrzpServiceClient client)
		{
			ImportStavType stav;
			string message;
			SeznamCiselnikuType response;

			int idDavky = client.CtiSeznamCiselniku(out stav, out message, out response);
			return new ResultCrate
			{
				IdDavky = idDavky,
				Stav = stav,
				Message = message,
				Response = SerializeToString(response)
			};
		}

		private static ResultCrate CtiCiselnik(NrzpServiceClient client, string nazevCiselniku, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			ImportStavType stav;
			string message;
			SeznamPolozekCiselnikuType response;
			int idDavky = client.CtiCiselnik(nazevCiselniku, out stav, out message, out response);
			return new ResultCrate
			{
				IdDavky = idDavky,
				Stav = stav,
				Message = message,
				Response = SerializeToString(response)
			};
		}

		private static ResultCrate CtiPodlePracovnikCislo(NrzpServiceClient client, string cisloNrzp, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long cislo;
			if (!long.TryParse(cisloNrzp, out cislo))
			{
				throw new Exception("Nepodařilo se převést číslo NRZP na typ long.");
			}

			ImportStavType stav;
			string message;
			PracovnikType response = client.CtiPodlePracovnikCislo(cislo, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out stav, out message);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = message,
				Response = SerializeToString(response)
			};
		}

		//private static ResultCrate CtiPodleUdaju(NrzpServiceClient client, string jmeno, string prijmeni, string datumNarozeni, string statMistaNarozeni, string rodneCislo, string cisloDokladu, string druhDokladu, string statniObcanstvi)
		//{
		//	string message;
		//	SeznamPracovnikuType seznamPracovniku;

		//	DokladType doklad = new DokladType();
		//	if (!string.IsNullOrEmpty(cisloDokladu) && !string.IsNullOrEmpty(druhDokladu))
		//	{
		//		try
		//		{
		//			DruhDokladuType druhDokladuTemp;
		//			if (Enum.IsDefined(typeof(DruhDokladuType), druhDokladu) && Enum.TryParse(druhDokladu, out druhDokladuTemp))
		//			{
		//				doklad.DruhDokladu = druhDokladuTemp;
		//				doklad.CisloDokladu = cisloDokladu;
		//			}
		//		}
		//		catch (ArgumentException)
		//		{
		//			Console.WriteLine("Druh dokladu není v číselníku.");
		//			throw;
		//		}
		//	}

		//	ImportStavType stav = client.CtiPodleUdaju(jmeno, prijmeni, datumNarozeni, statMistaNarozeni, rodneCislo, doklad, statniObcanstvi, out message, out seznamPracovniku);
		//	return new ResultCrate
		//			   {
		//				   IdDavky = 0,
		//				   Stav = stav,
		//				   Message = message,
		//				   Response = SerializeToString(seznamPracovniku)
		//			   };
		//}

		private static ResultCrate CtiPodleUdaju(NrzpServiceClient client, string prijmeni, string jmeno, string rodneCislo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			string message;
			SeznamPracovnikuType seznamPracovniku;

			ImportStavType stav = client.CtiPodleUdaju(jmeno, prijmeni, null, null, rodneCislo, null, null, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out message, out seznamPracovniku);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = message,
				Response = SerializeToString(seznamPracovniku)
			};
		}

		private static ResultCrate CtiPodleAifo(NrzpServiceClient client, string ulozkaId, string aifo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			int cislo;
			if (!int.TryParse(aifo, out cislo))
			{
				throw new Exception("Nepodařilo se převést číslo aifo na typ int.");
			}

			ImportStavType stav;
			string message;
			PracovnikType response = client.CtiPodleAifo(ulozkaId, cislo, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out stav, out message);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = message,
				Response = SerializeToString(response)
			};
		}

		private static ResultCrate SmazZamestnani(NrzpServiceClient client, string pracovnikNrzpCislo, string zamestnaniNrzpCislo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}
			long zamestnaniNrzp;
			if (!long.TryParse(zamestnaniNrzpCislo, out zamestnaniNrzp))
			{
				throw new Exception("Nepodařilo se převést ZamestnaniNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazZamestnani(pracovnikNrzp, zamestnaniNrzp, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		private static ResultCrate SmazVykonPovolani(NrzpServiceClient client, string pracovnikNrzpCislo, string vykonPovolaniNrzpCislo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}
			long vykonPovolaniNrzp;
			if (!long.TryParse(vykonPovolaniNrzpCislo, out vykonPovolaniNrzp))
			{
				throw new Exception("Nepodařilo se převést ZamestnaniNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazVykonPovolani(pracovnikNrzp, vykonPovolaniNrzp, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		private static ResultCrate SmazTitul(NrzpServiceClient client, string pracovnikNrzpCislo, string nazevTitulu, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazTitul(pracovnikNrzp, nazevTitulu, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		private static ResultCrate SmazPovolani(NrzpServiceClient client, string pracovnikNrzpCislo, string nazevPovolani, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazPovolani(pracovnikNrzp, nazevPovolani, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		private static ResultCrate SmazKmen(NrzpServiceClient client, string pracovnikNrzpCislo, string kmenNrzpCislo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}

			long kmenNrzp;
			if (!long.TryParse(kmenNrzpCislo, out kmenNrzp))
			{
				throw new Exception("Nepodařilo se převést KmenNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazKmen(pracovnikNrzp, kmenNrzp, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		private static ResultCrate SmazZvlastniOdbornouZpusobilost(NrzpServiceClient client, string pracovnikNrzpCislo, string zvlastniOdbornaZpusobilostNrzpCislo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}

			long zvlastniOdbornaZpusobilostNrzp;
			if (!long.TryParse(zvlastniOdbornaZpusobilostNrzpCislo, out zvlastniOdbornaZpusobilostNrzp))
			{
				throw new Exception("Nepodařilo se převést ZvlastniOdbornaZpusobilostNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazZvlastniOdbornouZpusobilost(pracovnikNrzp, zvlastniOdbornaZpusobilostNrzp, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		private static ResultCrate SmazSpecializovanouZpusobilost(NrzpServiceClient client, string pracovnikNrzpCislo, string specializovanaZpusobilostNrzpCislo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}

			long specializovanaZpusobilostNrzp;
			if (!long.TryParse(specializovanaZpusobilostNrzpCislo, out specializovanaZpusobilostNrzp))
			{
				throw new Exception("Nepodařilo se převést SpecializovanaZpusobilostNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazSpecializovanouZpusobilost(pracovnikNrzp, specializovanaZpusobilostNrzp, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		private static ResultCrate SmazOdbornouZpusobilost(NrzpServiceClient client, string pracovnikNrzpCislo, string zvlastniOdbornaZpusobilostNrzpCislo, string externiUzivatelLogin, string externiUzivatelJmenoAPrijmeni)
		{
			long pracovnikNrzp;
			if (!long.TryParse(pracovnikNrzpCislo, out pracovnikNrzp))
			{
				throw new Exception("Nepodařilo se převést PracovnikNrzpCislo na typ long.");
			}

			long zvlastniOdbornaZpusobilostNrzp;
			if (!long.TryParse(zvlastniOdbornaZpusobilostNrzpCislo, out zvlastniOdbornaZpusobilostNrzp))
			{
				throw new Exception("Nepodařilo se převést SpecializovanaZpusobilostNrzpCislo na typ long.");
			}

			SeznamValidaciType seznamValidaci;
			ImportStavType stav = client.SmazOdbornouZpusobilost(pracovnikNrzp, zvlastniOdbornaZpusobilostNrzp, externiUzivatelLogin, externiUzivatelJmenoAPrijmeni, out  seznamValidaci);
			return new ResultCrate
			{
				IdDavky = 0,
				Stav = stav,
				Message = string.Empty,
				Response = SerializeToString(seznamValidaci)
			};
		}

		#endregion

		class ResultCrate
		{
			public int IdDavky { get; set; }
			public ImportStavType Stav { get; set; }
			public string Message { get; set; }
			public string Response { get; set; }
			public object Item { get; set; }
		}

		private static T DeserializeObsah<T>(string fileName, string rootName, string rootNamespace)
		{
			var serializer = new DataContractSerializer(typeof(T), rootName, rootNamespace);
			var result = (T)serializer.ReadObject(new FileStream(fileName, FileMode.Open));
			return result;
		}
		private static string SerializeToString<T>(T objectToSerialize)
		{
			var serializer = new DataContractSerializer(typeof(T));
			var output = new StringBuilder();
			using (var xmlWriter = XmlWriter.Create(output))
			{
				serializer.WriteObject(xmlWriter, objectToSerialize);
				xmlWriter.Close();
			}
			return output.ToString();
		}

		public enum EnumMethod
		{
			zapispracovnika,
			ctiseznamciselniku,
			cticiselnik,
			ctipodlepracovnikcislo,
			ctipodleudaju,
			ctipodleaifo,
			smazzamestnani,
			smazvykonpovolani,
			smaztitul,
			smazpovolani,
			smazkmen,
			smazzvlastniodbornouzpusobilost,
			smazspecializovanouzpusobilost,
			smazodbornouzpusobilost,
			//import
		}
	}
}
